pygeodesy.auxilats.auxDLat

Package pygeodesy :: Package auxilats :: Module auxDLat |
[frames] | no frames]

# Module auxDLat

Class AuxDLat transcoded to Python from Karney's C++ class DAuxLatitude in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 26.01.20

Classes
| AuxDLat Class to compute `Divided Differences` of Auxiliary latitudes and other `Divided Differences` needed for RhumbAux and RhumbLineAux calculations.